@@ -30,7 +30,7 @@ int32_t SPVM__Sys__Time__localtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t* time_ref = stack[0].lref;
   
   if (!time_ref) {
-    return env->die_v2(env, stack, "The reference of the time $time_ref must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The reference of the time $time_ref must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   time_t time = *time_ref;
@@ -58,7 +58,7 @@ int32_t SPVM__Sys__Time__gmtime(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t* time_ref = stack[0].lref;
   
   if (!time_ref) {
-    return env->die_v2(env, stack, "The reference of the time $time_ref must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The reference of the time $time_ref must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   time_t time = *time_ref;
@@ -98,7 +98,7 @@ int32_t SPVM__Sys__Time__gettimeofday(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = gettimeofday(st_tv, st_tz);
   
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]gettimeofday() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]gettimeofday() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -112,7 +112,7 @@ int32_t SPVM__Sys__Time__clock(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t cpu_time = clock();
   
   if (cpu_time == -1) {
-    env->die_v2(env, stack, "[System Error]clock() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]clock() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -132,13 +132,13 @@ int32_t SPVM__Sys__Time__clock_gettime(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_tp = env->get_pointer(env, stack, obj_tp);
   }
   else {
-    return env->die_v2(env, stack, "$tp must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$tp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = clock_gettime(clk_id, st_tp);
   
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]clock_gettime() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]clock_gettime() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -158,13 +158,13 @@ int32_t SPVM__Sys__Time__clock_getres(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_res = env->get_pointer(env, stack, obj_res);
   }
   else {
-    return env->die_v2(env, stack, "The resolution time $res must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The resolution time $res must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = clock_getres(clk_id, st_res);
   
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]clock_getres() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]clock_getres() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -175,7 +175,7 @@ int32_t SPVM__Sys__Time__clock_getres(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__setitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die_v2(env, stack, "Sys::User#getitimer method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::User#getitimer method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -190,7 +190,7 @@ int32_t SPVM__Sys__Time__setitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_new_value = env->get_pointer(env, stack, obj_new_value);
   }
   else {
-    return env->die_v2(env, stack, "The new timer $new_value must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The new timer $new_value must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct itimerval* st_old_value = NULL;
@@ -201,7 +201,7 @@ int32_t SPVM__Sys__Time__setitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = setitimer(which, st_new_value, st_old_value);
   
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]setitimer() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]setitimer() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -213,7 +213,7 @@ int32_t SPVM__Sys__Time__setitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__getitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die_v2(env, stack, "Sys::User#getitimer method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::User#getitimer method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -226,13 +226,13 @@ int32_t SPVM__Sys__Time__getitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_curr_value = env->get_pointer(env, stack, obj_curr_value);
   }
   else {
-    return env->die_v2(env, stack, "$curr_value must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$curr_value must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t status = getitimer(which, st_curr_value);
   
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]getitimer() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]getitimer() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -244,13 +244,13 @@ int32_t SPVM__Sys__Time__getitimer(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__times(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die_v2(env, stack, "Sys::User#times method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::User#times method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_tms = stack[0].oval;
   
   if (!obj_tms) {
-    return env->die_v2(env, stack, "$tms must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$tms must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_tms);
@@ -259,7 +259,7 @@ int32_t SPVM__Sys__Time__times(SPVM_ENV* env, SPVM_VALUE* stack) {
   int64_t clock_tick = times(st_tms);
   
   if (errno != 0) {
-    env->die_v2(env, stack, "[System Error]times() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]times() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -271,13 +271,13 @@ int32_t SPVM__Sys__Time__times(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__clock_nanosleep(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef __APPLE__
-  env->die_v2(env, stack, "Sys::User#clock_nanosleep method is not supported in this system(__APPLE__).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::User#clock_nanosleep method is not supported in this system(__APPLE__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #elif __FreeBSD__ && !(__FreeBSD__ >= 13)
-  env->die_v2(env, stack, "Sys::User#clock_nanosleep method is not supported in this system(__FreeBSD__ && !(__FreeBSD__ >= 13)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::User#clock_nanosleep method is not supported in this system(__FreeBSD__ && !(__FreeBSD__ >= 13)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #elif __OpenBSD__
-  env->die_v2(env, stack, "Sys::User#clock_nanosleep method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::User#clock_nanosleep method is not supported in this system(__OpenBSD__).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -292,7 +292,7 @@ int32_t SPVM__Sys__Time__clock_nanosleep(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_request = env->get_pointer(env, stack, obj_request);
   }
   else {
-    return env->die_v2(env, stack, "The request time $request must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The request time $request must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_remain = stack[3].oval;
@@ -305,7 +305,7 @@ int32_t SPVM__Sys__Time__clock_nanosleep(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t ret_errno = clock_nanosleep(clockid, flags, st_request, st_remain);
   
   if (ret_errno != 0) {
-    env->die_v2(env, stack, "[System Error]clock_nanosleep() failed(%d: %s).", __func__, FILE_NAME, __LINE__, ret_errno, env->strerror_nolen(env, stack, ret_errno));
+    env->die(env, stack, "[System Error]clock_nanosleep() failed(%d: %s).", __func__, FILE_NAME, __LINE__, ret_errno, env->strerror_nolen(env, stack, ret_errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -326,7 +326,7 @@ int32_t SPVM__Sys__Time__nanosleep(SPVM_ENV* env, SPVM_VALUE* stack) {
     st_rqtp = env->get_pointer(env, stack, obj_rqtp);
   }
   else {
-    return env->die_v2(env, stack, "The request time $rqtp must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The request time $rqtp must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct timespec* st_rmtp = NULL;
@@ -337,7 +337,7 @@ int32_t SPVM__Sys__Time__nanosleep(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = nanosleep(st_rqtp, st_rmtp);
   
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]nanosleep() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
+    env->die(env, stack, "[System Error]nanosleep() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno));
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -355,7 +355,7 @@ int32_t SPVM__Sys__Time__utime(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_times = stack[1].oval;
   
   if (!obj_filename) {
-    return env->die_v2(env, stack, "The file path $filename must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file path $filename must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* filename = env->get_chars(env, stack, obj_filename);
   
@@ -369,7 +369,7 @@ int32_t SPVM__Sys__Time__utime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t status = utime(filename, st_times);
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]utime() failed(%d: %s). $filename='%s'.", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno), filename);
+    env->die(env, stack, "[System Error]utime() failed(%d: %s). $filename='%s'.", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno), filename);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
@@ -380,7 +380,7 @@ int32_t SPVM__Sys__Time__utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__utimes(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die_v2(env, stack, "Sys::User#utimes method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::User#utimes method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -390,18 +390,18 @@ int32_t SPVM__Sys__Time__utimes(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_times = stack[1].oval;
   
   if (!obj_filename) {
-    return env->die_v2(env, stack, "The file path $filename must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The file path $filename must be defined.", __func__, FILE_NAME, __LINE__);
   }
   const char* filename = env->get_chars(env, stack, obj_filename);
   
   if (!obj_times) {
-    return env->die_v2(env, stack, "The utime infomation $times must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The utime infomation $times must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t times_length = env->length(env, stack, obj_times);
   
   if (!(times_length == 2)) {
-    return env->die_v2(env, stack, "The length of the utime infomation $times must be 2.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length of the utime infomation $times must be 2.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_times0 = env->get_elem_object(env, stack, obj_times, 0);
@@ -415,7 +415,7 @@ int32_t SPVM__Sys__Time__utimes(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t status = utimes(filename, times);
   
   if (status == -1) {
-    env->die_v2(env, stack, "[System Error]utimes() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno), filename);
+    env->die(env, stack, "[System Error]utimes() failed(%d: %s).", __func__, FILE_NAME, __LINE__, errno, env->strerror_nolen(env, stack, errno), filename);
     return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS;
   }
   
